==> haskell-hakyll-4.7.5.1-37-armv7h.pkg.tar.xz: usr/share/haskell/haskell-hakyll/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hakyll
version: 4.7.5.1
id: hakyll-4.7.5.1-fa2ef4fc5779f252c143b6c71ce91e00
key: hakyl_GlB0oYJSfEU54FfhImIDIF
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: http://jaspervdj.be/hakyll
synopsis: A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:
    .
    * <http://jaspervdj.be/hakyll>
    .
    If you seek assistance, there'\''s:
    .
    * A google group: <http://groups.google.com/group/hakyll>
    .
    * An IRC channel, @#hakyll@ on freenode
    .
    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.
category: Web
author: Jasper Van der Jeugt <m@jaspervdj.be>
exposed: True
exposed-modules:
    Hakyll Hakyll.Core.Compiler Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item
    Hakyll.Core.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.UnixFilter Hakyll.Core.Util.String Hakyll.Core.Writable
    Hakyll.Main Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Pandoc
    Hakyll.Web.Pandoc.Biblio Hakyll.Web.Pandoc.FileType Hakyll.Web.Tags
    Hakyll.Web.Paginate Hakyll.Web.Template
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Context
    Hakyll.Web.Template.List
hidden-modules: Hakyll.Check Hakyll.Commands
                Hakyll.Core.Compiler.Internal Hakyll.Core.Compiler.Require
                Hakyll.Core.Item.SomeItem Hakyll.Core.Logger Hakyll.Core.Provider
                Hakyll.Core.Provider.Internal Hakyll.Core.Provider.Metadata
                Hakyll.Core.Provider.MetadataCache Hakyll.Core.Rules.Internal
                Hakyll.Core.Runtime Hakyll.Core.Store Hakyll.Core.Util.File
                Hakyll.Core.Util.Parser Hakyll.Web.Pandoc.Binary Paths_hakyll
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.7.5.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.7.5.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/hakyll-4.7.5.1
hs-libraries: HShakyll-4.7.5.1-GlB0oYJSfEU54FfhImIDIF
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cmdargs-0.10.14-ea4d1877c8c5fa6ed8eebd52f962ac3b
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    http-conduit-2.1.8-288436503dec7c7ed70373ac0e4730a6
    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
    lrucache-1.2.0.0-97fd799690b7e95999ded6be87e87c88
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
    pandoc-1.16.0.2-1e3210a759893e8cb19c047605eb93fb
    pandoc-citeproc-0.9-82d758a0aade0504e63eea3491cf7af5
    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    regex-base-0.93.2-42cdf19dc92d6af642a96da5984c8c2c
    regex-tdfa-1.2.1-2f2ff40a952b63109ef37be1ffea97d0
    tagsoup-0.13.8-ae67a6a9bc7b71798dd8f975b70085f0
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    time-locale-compat-0.1.1.1-4bbdeebce90c671369911a4d16cfee44
haddock-interfaces: /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html: /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hakyll-4.7.5.1-38-armv7h.pkg.tar.xz: usr/share/haskell/haskell-hakyll/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hakyll
version: 4.7.5.1
id: hakyll-4.7.5.1-378313a4bda08c68789ba8bf5e35c93d
key: hakyl_61oDvASVaUwCRjAZ3CwJXx
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: http://jaspervdj.be/hakyll
synopsis: A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:
    .
    * <http://jaspervdj.be/hakyll>
    .
    If you seek assistance, there'\''s:
    .
    * A google group: <http://groups.google.com/group/hakyll>
    .
    * An IRC channel, @#hakyll@ on freenode
    .
    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.
category: Web
author: Jasper Van der Jeugt <m@jaspervdj.be>
exposed: True
exposed-modules:
    Hakyll Hakyll.Core.Compiler Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item
    Hakyll.Core.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.UnixFilter Hakyll.Core.Util.String Hakyll.Core.Writable
    Hakyll.Main Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Pandoc
    Hakyll.Web.Pandoc.Biblio Hakyll.Web.Pandoc.FileType Hakyll.Web.Tags
    Hakyll.Web.Paginate Hakyll.Web.Template
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Context
    Hakyll.Web.Template.List
hidden-modules: Hakyll.Check Hakyll.Commands
                Hakyll.Core.Compiler.Internal Hakyll.Core.Compiler.Require
                Hakyll.Core.Item.SomeItem Hakyll.Core.Logger Hakyll.Core.Provider
                Hakyll.Core.Provider.Internal Hakyll.Core.Provider.Metadata
                Hakyll.Core.Provider.MetadataCache Hakyll.Core.Rules.Internal
                Hakyll.Core.Runtime Hakyll.Core.Store Hakyll.Core.Util.File
                Hakyll.Core.Util.Parser Hakyll.Web.Pandoc.Binary Paths_hakyll
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.7.5.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.7.5.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/hakyll-4.7.5.1
hs-libraries: HShakyll-4.7.5.1-61oDvASVaUwCRjAZ3CwJXx
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cmdargs-0.10.14-ea4d1877c8c5fa6ed8eebd52f962ac3b
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    http-conduit-2.1.8-3cbd23ba75c7bf6ee8e4c2285c87f4dc
    http-types-0.9-181a315082d46c3ed5dffe75933f2447
    lrucache-1.2.0.0-97fd799690b7e95999ded6be87e87c88
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
    pandoc-1.16.0.2-31f468e05a5caa86237ccb0bcb6308ba
    pandoc-citeproc-0.9-1d62a0bc83cc5a76018a3fc21732faa7
    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    regex-base-0.93.2-42cdf19dc92d6af642a96da5984c8c2c
    regex-tdfa-1.2.1-2f2ff40a952b63109ef37be1ffea97d0
    tagsoup-0.13.9-50d5019a7872f558763ae9548d877c82
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    time-locale-compat-0.1.1.1-4bbdeebce90c671369911a4d16cfee44
haddock-interfaces: /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html: /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
